@@ -71,8 +71,8 @@ bool Game::start(const QString &command)
     // Test if we started a GTP-compatible Go game
     m_process.write("name\n");
     m_process.waitForReadyRead();
-    const QString response = m_process.readAllStandardOutput();
-    if (response.isEmpty() || !response.startsWith(QLatin1Char('='))) {
+    const QByteArray response = m_process.readAllStandardOutput();
+    if (response.isEmpty() || !response.startsWith('=')) {
         m_response = QStringLiteral("Game did not respond to GTP command \"name\"");
         //qCDebug(KIGO_LOG) << m_response;
         stop();
@@ -314,19 +314,19 @@ bool Game::playMove(const Player &player, const Stone &stone, bool undoable)
                 playerTemp = &m_whitePlayer;
                 if (stone.isValid()) {
                     moveType = UndoCommand::MoveType::Stone;
-                    undoStr = i18nc("%1 stone coordinate", "White %1", stone.toString());
+                    undoStr = i18nc("@item undo/redo, %1 stone coordinate", "White %1", stone.toString());
                 } else {
                     moveType = UndoCommand::MoveType::Passed;
-                    undoStr = i18n("White passed");
+                    undoStr = i18nc("@item undo/redo", "White passed");
                 }
             } else {
                 playerTemp = &m_blackPlayer;
                 if (stone.isValid()) {
                     moveType = UndoCommand::MoveType::Stone;
-                    undoStr = i18nc("%1 stone coordinate", "Black %1", stone.toString());
+                    undoStr = i18nc("@item undo/redo, %1 stone coordinate", "Black %1", stone.toString());
                 } else {
                     moveType = UndoCommand::MoveType::Passed;
-                    undoStr = i18n("Black passed");
+                    undoStr = i18nc("@item undo/redo", "Black passed");
                 }
             }
             //qCDebug(KIGO_LOG) << "Push new undo command" << undoStr;
@@ -387,18 +387,18 @@ bool Game::generateMove(const Player &player, bool undoable)
             m_consecutivePassMoveNumber++;
             moveType = UndoCommand::MoveType::Passed;
             if (tmp->isWhite()) {
-                undoStr = i18n("White passed");
+                undoStr = i18nc("@item undo/redo", "White passed");
             } else {
-                undoStr = i18n("Black passed");
+                undoStr = i18nc("@item undo/redo", "Black passed");
             }
         } else if (m_response == QLatin1String("resign")) {
             Q_EMIT resigned(*m_currentPlayer);
             m_gameFinished = true;
             moveType = UndoCommand::MoveType::Resigned;
             if (tmp->isWhite()) {
-                undoStr = i18n("White resigned");
+                undoStr = i18nc("@item undo/redo", "White resigned");
             } else {
-                undoStr = i18n("Black resigned");
+                undoStr = i18nc("@item undo/redo", "Black resigned");
             }
         } else {
             m_currentMove++;
@@ -406,9 +406,9 @@ bool Game::generateMove(const Player &player, bool undoable)
             m_consecutivePassMoveNumber = 0;
             moveType = UndoCommand::MoveType::Stone;
             if (tmp->isWhite()) {
-                undoStr = i18nc("%1 response from Go engine", "White %1", m_response);
+                undoStr = i18nc("@item undo/redo, %1 response from Go engine", "White %1", m_response);
             } else {
-                undoStr = i18nc("%1 response from Go engine", "Black %1", m_response);
+                undoStr = i18nc("@item undo/redo, %1 response from Go engine", "Black %1", m_response);
             }
             boardChange = true;
         }
@@ -713,8 +713,8 @@ bool Game::waitResponse(bool nonBlocking)
             case QProcess::FailedToStart: m_response = QStringLiteral("No Go game is running!"); break;
             case QProcess::Crashed: m_response = QStringLiteral("The Go game crashed!"); break;
             case QProcess::Timedout: m_response = QStringLiteral("The Go game timed out!"); break;
-            case QProcess::WriteError: m_response = m_process.readAllStandardError(); break;
-            case QProcess::ReadError: m_response = m_process.readAllStandardError(); break;
+            case QProcess::WriteError: m_response = QString::fromLocal8Bit(m_process.readAllStandardError()); break;
+            case QProcess::ReadError: m_response = QString::fromLocal8Bit(m_process.readAllStandardError()); break;
             case QProcess::UnknownError: m_response = QStringLiteral("Unknown error!"); break;
         }
         qCWarning(KIGO_LOG) << "Command failed:" << m_response;
@@ -741,7 +741,7 @@ bool Game::waitResponse(bool nonBlocking)
         } else {
             m_process.waitForReadyRead();       // Blocking wait
         }
-        m_response += m_process.readAllStandardOutput();
+        m_response += QString::fromLocal8Bit(m_process.readAllStandardOutput());
     } while (!m_response.endsWith(QLatin1String("\r\r")) &&
              !m_response.endsWith(QLatin1String("\n\n")) &&
              !m_response.endsWith(QLatin1String("\r\n\r\n")));
